/***************************************************************************
                          socks5.cpp  -  description
                             -------------------
    begin                : Sat Feb 19 2000
    copyright            : (C) 2000 by jade
    email                : donoghue@chariot.net.au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include <netdb.h>
#include <sys/socket.h>
#include <sys/time.h>
#include <unistd.h>
#include <arpa/tftp.h>

#include "knapster.h"

// maybe I'll get around to adding this stuff at some
// stage
//
int sock_connect(int sock,sockaddr *caddr,int sz)
{
//  struct sockaddr_in saddr;


  return -1;
}

